# coding: utf-8

""" ctl for everything that can't be done without python """

from sys import argv
from dictator import Dictator
from logging import log, FATAL

def auth():
    user, token, secret = argv[2:]
    d = Dictator()
    user_data = d[user]
    user_data[2], user_data[3] = token, secret
    d[user] = user_data


def main():
    commands = {
        'auth': auth,
    }
    
    assert argv[1] in commands, "Unknown command {0}".format(argv[1])
    commands.get(argv[1])()


if __name__ == '__main__':
    main()



from bot import Bot


class Writer(Bot):

    """ Reads tweets from reader db. Templating, filter (rate and duplicate) and post. """

    def __init__(self, username, host='127.0.0.1'):
        Bot.__init__(self, username, host)
        self.last_tweet_id = int(self.connection.get('__last_tweet_id__', 1))

    def tweet(self, key, result):
        tweet = unicode(self.template, 'utf-8').format(result).encode('utf-8')
        tweet_rc = self.twibot.api.update_status(tweet)
        # pylint: disable=E1101
        self.connection[result] = tweet_rc.id
        self.connection['__last_tweet_id__'] = key

    def unprocessed_lines(self):
        return [(key, value) for key, value in self.reader.items() if key.isdigit() and int(key)
                > int(self.last_tweet_id)]

    def is_already_posted(self, words):
        return self.connection.get(words)

    def is_words_bad(self, words):
        return any(int(self.analyzer.get(word)) < -10 for word in words)



""" redis/auth manager and Twibot connector """

from dictator import Dictator
from twitterbot_utils import Twibot


# pylint: disable=R0903
class Bot(object):
    """ redis/auth manager and Twibot connector """

    def __init__(self, username, host='127.0.0.1'):
        auth = Dictator(host=host)
        consumer_key, consumer_secret = auth.get('__app__')
        user = auth.get('@' + username)
        role, db_id, access_token, access_secret = user[:4]
        if role == 'writer':
            reader_id, analyzer_id, self.template = user[4:7]
            self.reader = Dictator(host=host, db=reader_id)
            self.analyzer = Dictator(host=host, db=analyzer_id)
        self.connection = Dictator(host=host, db=db_id)
        self.twibot = Twibot(method='params',
                             consumer_key=consumer_key,
                             consumer_secret=consumer_secret,
                             access_token=access_token,
                             access_secret=access_secret)



from bot import Bot


class Analyzer(Bot):
    """
    1. Reads writer feed
    2. counts likes/retweets
    3. modifies words/phrases rates
    """

    def __init__(self, username):
        Bot.__init__(self, username)
        self.last_tweet_id = int(self.connection.get('__last_tweet_id__', 1))

    def fetch(self):
        pass

    def update_rate(self, word):
        pass



#!/usr/bin/env python
from bot import Bot


class Reader(Bot):
    """ Reads fead and stores them into redis db. """

    def __init__(self, username):
        Bot.__init__(self, username)
        self.last_tweet_id = int(self.connection.get('__last_tweet_id__', 1))

    def save(self, tweet_list):
        for tweet in tweet_list:
            self.connection[tweet.id] = tweet.text
        self.connection['__last_tweet_id__'] = self.last_tweet_id

    def fetch(self):
        tweet_list = self.twibot.api.home_timeline(since_id=self.last_tweet_id, count=200)
        self.last_tweet_id = max(tweet.id for tweet in tweet_list)
        self.save(tweet_list)



#!/usr/bin/env python

'''The setup and build script for the twitterbot-farm library.'''

import os

from setuptools import setup, find_packages


def read(*paths):
    """Build a file path from *paths* and return the contents."""
    with open(os.path.join(*paths), 'r') as f:
        return f.read()


setup(
    name='twitterbot_farm',
    version='0.1.3',
    author='Oleg Strizhechenko',
    author_email='oleg.strizhechenko@gmail.com',
    license='GPL',
    url='https://github.com/strizhechenko/twitterbot_farm',
    keywords='twitter api bot farm',
    description='"Framework" for running a lot of twitterbots without useless twitter API calls.',
    long_description=(read('README.rst')),
    packages=find_packages(exclude=['tests*']),
    scripts=['utils/tfctl', 'utils/tfctl.py'],
    install_requires=['twitterbot-utils>=0.1.8', 'dictator'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Operating System :: MacOS',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Topic :: Software Development',
        'Topic :: Utilities',
    ],
)
